@@ -1,7 +1,7 @@
 # ##############################################################################
 #  This file is part of df_config                                              #
 #                                                                              #
-#  Copyright (C) 2020 Matthieu Gallet <github@19pouces.net>                    #
+#  Copyright (C) 2020 Matthieu Gallet <df_config@19pouces.net>                    #
 #  All Rights Reserved                                                         #
 #                                                                              #
 #  You may use, distribute and modify this code under the                      #
@@ -16,6 +16,7 @@
 import base64
 import binascii
 import logging
+from functools import lru_cache
 
 from django.conf import settings
 from django.contrib import auth
@@ -24,10 +25,12 @@ from django.contrib.auth.middleware import (
 )
 from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpRequest
+from django.utils.functional import cached_property
 
 logger = logging.getLogger("django.request")
 
 
+
 class DFConfigMiddleware(BaseRemoteUserMiddleware):
     """Like :class:`django.contrib.auth.middleware.RemoteUserMiddleware` but:
 
@@ -37,9 +40,13 @@ class DFConfigMiddleware(BaseRemoteUserMiddleware):
     * set response header for Internet Explorer (to use its most recent render engine)
     """
 
-    header = settings.DF_REMOTE_USER_HEADER
-    if header:
-        header = header.upper().replace("-", "_")
+    @lru_cache()
+    def get_remoteuser_header(self):
+        # avoid cached_property to ease unittests
+        header = settings.DF_REMOTE_USER_HEADER
+        if header:
+            header = header.upper().replace("-", "_")
+        return header
 
     def process_request(self, request: HttpRequest):
         request.remote_username = None
@@ -66,10 +73,12 @@ class DFConfigMiddleware(BaseRemoteUserMiddleware):
                         request.user = user
                         auth.login(request, user)
         username = getattr(settings, "DF_FAKE_AUTHENTICATION_USERNAME", None)
-        if self.header and username and settings.DEBUG:
+
+        header = self.get_remoteuser_header()
+        if header and username and settings.DEBUG:
             remote_addr = request.META.get("REMOTE_ADDR")
             if remote_addr in settings.INTERNAL_IPS:
-                request.META[self.header] = username
+                request.META[header] = username
             elif remote_addr:
                 logger.warning(
                     "Unable to use `settings.DF_FAKE_AUTHENTICATION_USERNAME`. "
@@ -77,8 +86,8 @@ class DFConfigMiddleware(BaseRemoteUserMiddleware):
                     % remote_addr
                 )
 
-        if self.header and self.header in request.META:
-            remote_username = request.META.get(self.header)
+        if header and header in request.META:
+            remote_username = request.META.get(header)
             if (
                 not remote_username or remote_username == "(null)"
             ):  # special case due to apache2+auth_mod_kerb :-(
