@@ -1,7 +1,7 @@
 # ##############################################################################
 #  This file is part of df_config                                              #
 #                                                                              #
-#  Copyright (C) 2020 Matthieu Gallet <github@19pouces.net>                    #
+#  Copyright (C) 2020 Matthieu Gallet <df_config@19pouces.net>                    #
 #  All Rights Reserved                                                         #
 #                                                                              #
 #  You may use, distribute and modify this code under the                      #
@@ -66,17 +66,17 @@ from df_config.guesses.auth import (
 from df_config.guesses.databases import (
     cache_redis_url,
     cache_setting,
-    celery_redis_url,
+    celery_broker_url,
     databases,
     session_redis_dict,
     websocket_redis_dict,
-    websocket_redis_channels,
+    websocket_redis_channels, celery_result_url,
 )
 from df_config.guesses.log import log_configuration
 from df_config.guesses.misc import (
     DefaultListenAddress,
     allowed_hosts,
-    excluded_django_commands,
+    csrf_trusted_origins, excluded_django_commands,
     project_name,
     required_packages,
     secure_hsts_seconds,
@@ -106,13 +106,6 @@ from df_config.guesses.staticfiles import (
 )
 from df_config.utils import guess_version, is_package_present
 
-try:
-    import django_redis  # does not work with is_package_present (???)
-
-    USE_REDIS_CACHE = True
-except ImportError:
-    django_redis = None
-    USE_REDIS_CACHE = False
 USE_CELERY = is_package_present("celery")
 USE_REDIS_SESSIONS = is_package_present("redis_sessions")
 USE_PIPELINE = is_package_present("pipeline")
@@ -138,7 +131,7 @@ CSRF_COOKIE_HTTPONLY = False
 CSRF_COOKIE_NAME = CallableSetting(CookieName("csrftoken"))
 CSRF_COOKIE_SAMESITE = "Lax"
 CSRF_COOKIE_SECURE = SettingReference("USE_SSL")
-CSRF_TRUSTED_ORIGINS = ["{SERVER_NAME}", "{SERVER_NAME}:{SERVER_PORT}"]
+CSRF_TRUSTED_ORIGINS = CallableSetting(csrf_trusted_origins)
 DATABASES = CallableSetting(databases)
 
 DEBUG = False
@@ -228,11 +221,11 @@ STATICFILES_STORAGE = CallableSetting(static_storage)
 STATICFILES_FINDERS = CallableSetting(static_finder)
 
 # celery
-BROKER_URL = CallableSetting(celery_redis_url)
+BROKER_URL = CallableSetting(celery_broker_url)
 CELERY_DEFAULT_QUEUE = "celery"
 CELERY_TIMEZONE = "{TIME_ZONE}"
 CELERY_RESULT_EXCHANGE = "{DF_MODULE_NAME}_results"
-CELERY_RESULT_BACKEND = "{BROKER_URL}"
+CELERY_RESULT_BACKEND = CallableSetting(celery_result_url)
 CELERY_RESULT_SERIALIZER = "json"
 CELERY_ACCEPT_CONTENT = ["json", "yaml", "msgpack"]
 CELERY_APP = "df_websockets"
@@ -271,6 +264,7 @@ WEBSOCKET_TOPIC_SERIALIZER = "df_websockets.topics.serialize_topic"
 WEBSOCKET_SIGNAL_ENCODER = "django.core.serializers.json.DjangoJSONEncoder"
 WEBSOCKET_REDIS_PREFIX = "ws"
 WEBSOCKET_REDIS_EXPIRE = 36000
+
 WINDOW_INFO_MIDDLEWARES = [
     "df_websockets.ws_middleware.WindowKeyMiddleware",
     "df_websockets.ws_middleware.DjangoAuthMiddleware",
@@ -544,21 +538,30 @@ CACHE_PORT = 6379  # aliased in settings.ini as "[cache]port"
 CACHE_DB = 2  # aliased in settings.ini as "[cache]db"
 CACHE_PASSWORD = None  # aliased in settings.ini as "[cache]password"
 
-# websockets
-WEBSOCKET_REDIS_PROTOCOL = "redis"
-WEBSOCKET_REDIS_HOST = "localhost"  # aliased in settings.ini as "[websocket]host"
-WEBSOCKET_REDIS_PORT = 6379  # aliased in settings.ini as "[websocket]port"
-WEBSOCKET_REDIS_DB = 3  # aliased in settings.ini as "[websocket]db"
-WEBSOCKET_REDIS_PASSWORD = None  # aliased in settings.ini as "[websocket]password"
-
 # celery
 CELERY_PROTOCOL = "redis"
 CELERY_HOST = "localhost"  # aliased in settings.ini as "[celery]host"
 CELERY_PORT = 6379  # aliased in settings.ini as "[celery]port"
 CELERY_DB = 4  # aliased in settings.ini as "[celery]db"
 CELERY_PASSWORD = None  # aliased in settings.ini as "[celery]password"
+CELERY_USERNAME = None  # only useful for amqp
 CELERY_PROCESSES = 4
 
+# celery
+CELERY_RESULT_PROTOCOL = SettingReference("CELERY_PROTOCOL")
+CELERY_RESULT_HOST = SettingReference("CELERY_HOST")
+CELERY_RESULT_PORT = SettingReference("CELERY_PORT")
+CELERY_RESULT_DB = SettingReference("CELERY_DB")
+CELERY_RESULT_PASSWORD = SettingReference("CELERY_PASSWORD")
+CELERY_RESULT_USERNAME = SettingReference("CELERY_USERNAME")
+
+# df_websockets
+WEBSOCKET_REDIS_PROTOCOL = "redis"
+WEBSOCKET_REDIS_HOST = "localhost"
+WEBSOCKET_REDIS_PORT = 6379
+WEBSOCKET_REDIS_DB = 1
+WEBSOCKET_REDIS_PASSWORD = None
+
 # sentry.io
 USE_SENTRY = CallableSetting(use_sentry)
 SENTRY_DSN = None
