@@ -1,7 +1,7 @@
 # ##############################################################################
 #  This file is part of df_config                                              #
 #                                                                              #
-#  Copyright (C) 2020 Matthieu Gallet <github@19pouces.net>                    #
+#  Copyright (C) 2020 Matthieu Gallet <df_config@19pouces.net>                    #
 #  All Rights Reserved                                                         #
 #                                                                              #
 #  You may use, distribute and modify this code under the                      #
@@ -203,9 +203,11 @@ class LogConfiguration:
     access_loggers = {
         "aiohttp.access": _level_access,
         "django.server": _level_access,
+        "django.channels.server": _level_access,
         "geventwebsocket.handler": _level_access,
         "gunicorn.access": _level_access,
     }
+
     problem_loggers = {
         "django": _level_up,
         "django.db": _level_up,
@@ -236,6 +238,7 @@ class LogConfiguration:
         self.excluded_commands = {}
         self.stdout = stdout or sys.stdout
         self.stderr = stderr or sys.stderr
+        self.log_directory_warning = False  # True when a warning has been emitted
 
     def __call__(self, settings_dict, argv=None):
         if argv is None:
@@ -292,9 +295,9 @@ class LogConfiguration:
                 self.add_handler(logger, "access", level="DEBUG", formatter="nocolor")
             has_handler = True
 
-        has_handler = has_handler or self.add_remote_collector(
-            settings_dict["LOG_REMOTE_URL"], settings_dict["LOG_REMOTE_ACCESS"]
-        )
+        has_handler = self.add_remote_collector(
+            settings_dict["LOG_REMOTE_URL"], settings_dict["LOG_REMOTE_ACCESS"], level=log_level
+        ) or has_handler
         if not has_handler or not self.log_suffix:
             # (no file or interactive command) and no logd/syslog => we print to the console (like the debug mode)
             self.add_handler("ROOT", "stdout", level=log_level, formatter="colorized")
@@ -308,7 +311,7 @@ class LogConfiguration:
     def __repr__(self):
         return "%s.%s" % (self.__module__, "log_configuration")
 
-    def add_remote_collector(self, log_remote_url, log_remote_access):
+    def add_remote_collector(self, log_remote_url, log_remote_access, level="WARN"):
         has_handler = False
         if not log_remote_url:
             return has_handler
@@ -322,7 +325,7 @@ class LogConfiguration:
             self.add_handler(
                 "ROOT",
                 "syslog",
-                level="WARN",
+                level=level,
                 address=address,
                 facility=facility,
                 socktype=socktype,
@@ -476,13 +479,15 @@ class LogConfiguration:
         else:  # basename of a plain-text log
             log_directory = os.path.normpath(self.log_directory)
             if not os.path.isdir(log_directory):
-                warning = Warning(
-                    'Missing directory, you can create it with \nmkdir -p "%s"'
-                    % log_directory,
-                    hint=None,
-                    obj=log_directory,
-                )
-                settings_check_results.append(warning)
+                if not self.log_directory_warning:
+                    warning = Warning(
+                        'Missing directory "%s"'
+                        % log_directory,
+                        hint=None,
+                        obj=log_directory,
+                    )
+                    settings_check_results.append(warning)
+                    self.log_directory_warning = True
                 self.add_handler(logger, "stdout", level=level, **kwargs)
                 return
             basename = "%s-%s.log" % (self.log_suffix, filename)
@@ -503,6 +508,7 @@ class LogConfiguration:
                 )
                 settings_check_results.append(warning_)
                 self.add_handler(logger, "stdout", level=level, **kwargs)
+                return
             handler_name = "%s.%s" % (self.log_suffix, filename)
             handler = {
                 "class": "logging.handlers.RotatingFileHandler",
@@ -511,14 +517,19 @@ class LogConfiguration:
                 "formatter": "nocolor",
                 "filename": log_filename,
                 "level": level,
+                "delay": True,
             }
 
+        if not handler_name:
+            return
         if handler_name not in self.handlers:
             self.handlers[handler_name] = handler
         if logger == "ROOT":
-            self.root["handlers"].append(handler_name)
+            target = self.root
         else:
-            self.loggers[logger]["handlers"].append(handler_name)
+            target = self.loggers[logger]
+        if handler_name not in target["handlers"]:
+            target["handlers"].append(handler_name)
 
     @staticmethod
     def get_smart_command_name(module_name, argv, excluded_commands=None):
