@@ -1,7 +1,7 @@
 # ##############################################################################
 #  This file is part of df_config                                              #
 #                                                                              #
-#  Copyright (C) 2020 Matthieu Gallet <github@19pouces.net>                    #
+#  Copyright (C) 2020 Matthieu Gallet <df_config@19pouces.net>                    #
 #  All Rights Reserved                                                         #
 #                                                                              #
 #  You may use, distribute and modify this code under the                      #
@@ -39,7 +39,7 @@ class Command(BaseCommand):
         "show the current configuration."
         'Can display as python file ("config python") or as .ini file ("config ini"). Use -v 2 to display more info.'
     )
-    requires_system_checks = False
+    requires_system_checks = []
     options = {
         "python": "display the current config as Python module",
         "ini": "display the current config as .ini file",
@@ -75,7 +75,6 @@ class Command(BaseCommand):
             fd = io.StringIO()
             self.stdout = OutputWrapper(fd)
             self.style = no_style()
-
         if action == "python":
             self.show_python_config(verbosity)
         elif action == "ini":
@@ -129,12 +128,13 @@ class Command(BaseCommand):
             if not isinstance(provider, EnvironmentConfigProvider):
                 continue
             prefix = provider.prefix
+            mapping_attribute = provider.mapping_attribute
         if not prefix:
             self.stderr.write("Environment variables are not used•")
             return
         if verbosity >= 2:
             self.stdout.write(self.style.SUCCESS("# read environment variables:"))
-        provider = EnvironmentConfigProvider(prefix)
+        provider = EnvironmentConfigProvider(prefix, mapping_attribute)
         merger.write_provider(provider, include_doc=verbosity >= 2)
         self.stdout.write(provider.to_str())
 
